<?php

/**
* @author Philipp Bochskandl
*/

class WpsspAdminPage {
	
	private $input_fields = array();
	private $sections     = array();
	public static $page   = WPSSP_PREFIX;
	
	public static function init() {
		new WpsspAdminPage();
	}

	public function get_settings_group() {
		return WPSSP_PREFIX . '_options';
	}
	
	public function add_section($section) {
		array_push($this->sections, $section);
	}

	public function __construct() {
		
		register_setting( 'wpssp-settings-group', $this->get_settings_group() );

		//  $id, $title, $callback, $page
		$this->add_section( new WpsspSection('g', 'Allgemeines', array(__CLASS__, 'admin_general_description'), WpsspAdminPage::$page));
		$this->add_section( new WpsspSection('fb', 'Facebook', array(__CLASS__, 'admin_facebook_description'), WpsspAdminPage::$page));
		$this->add_section( new WpsspSection('tw', 'Twitter', array(__CLASS__, 'admin_twitter_description'), WpsspAdminPage::$page));
		$this->add_section( new WpsspSection('gp', 'Google+', array(__CLASS__, 'admin_gplus_description'), WpsspAdminPage::$page));
	}
	
	function admin_general_description() {
		?><p><b>Wenn Optionen leergelassen werden, wird der Standardwert aus dem Heise-Plugin verwendet.</b></p><?php
	}
	
	function admin_facebook_description() {
		// enntfernt
	}
	
	function admin_twitter_description() {
		echo '<p>Einstellungen für Twitter. Im Feld "Status" das Wort <code>off</code> eingeben, um Twitter zu deaktivieren.</p>';
	}
	
	function admin_gplus_description() {
		echo '<p>Einstellungen für Google+. Im Feld "Status" das Wort <code>off</code> eingeben, um Google+ zu deaktivieren.</p>';
	}
}

class WpsspSection {
	
	private $name;
	private $caption;
	private $description_callback;
	
	public function __construct($name, $caption, $description_callback ) {
		$this->name = $name;
		$this->caption = $caption;
		$this->description_callback = $description_callback;
		add_settings_section( WPSSP_PREFIX . '_' . $name, $caption, $description_callback, WpsspAdminPage::$page);
		$this->create_content();
	}
	
	public function create_content() {
		
		new InputField( 'info_link', 'Info-Link', 'wpssp_g', 'Link zu detaillierter Datenschutz-Info', 'code' );
		new InputField( 'txt_help', 'Hilfetext', 'wpssp_g', 'MouseOver-Text des <em>i</em>-Icons' );
		new InputField( 'settings_perma', 'Info-Text', 'wpssp_g', 'Überschrift des Einstellungsmenüs' );
		new InputField( 'cookie_domain', 'Cookie-Domain', 'wpssp_g', 'Domain, für die das Cookie gültig ist. Standard (nicht ausgefüllt): aktuelle Domain', 'code' );
		new InputField( 'cookie_path', 'Cookie-Path', 'wpssp_g', 'Pfad der Gültigkeit des Cookies', 'code' );
		new InputField( 'cookie_expire', 'Cookie-Expire-Time', 'wpssp_g', 'Dauer, die das Cookie gültig ist, in Tagen', 'code' );

		new InputField( 'services_facebook_status', '<b>Facebook-Button anzeigen</b>', 'wpssp_fb', '<code>on</code>, wenn aktiviert, andernfalls <code>off</code>', '', 'checkbox');
		new InputField( 'services_facebook_display_name', 'Anzeigename', 'wpssp_fb', 'Schreibweise des Service in den Optionen' );
		new InputField( 'services_facebook_txt_info', 'Info-Text', 'wpssp_fb', 'MouseOver-Text des Empfehlen-Buttons' );
		new InputField( 'services_facebook_txt_fb_on', 'Statusmeldung <code>on</code>', 'wpssp_fb', 'Text-Entsprechung der Schalter-Grafik im eingeschalteten Zustand, in der Regel nicht sichtbar für den User');
		new InputField( 'services_facebook_txt_fb_off', 'Statusmeldung <code>off</code>', 'wpssp_fb', 'Text-Entsprechung der Schalter-Grafik im ausgeschalteten Zustand, in der Regel nicht sichtbar für den User');
		new InputField( 'services_facebook_referrer_track', 'Referrer Track', 'wpssp_fb', 'Wird ans Ende der URL gehängt, kann zum Tracken des Referrers genutzt werden', 'code' );
		new InputField( 'services_facebook_language', 'Sprache', 'wpssp_fb', 'Spracheinstellung, etwa "de_DE"', 'code');

		new InputField( 'services_twitter_status', '<b>Twitter-Button anzeigen</b>', 'wpssp_tw', '<code>on</code>, wenn aktiviert, andernfalls <code>off</code>', '', 'checkbox' );
		new InputField( 'services_twitter_tweet_text', 'Tweet-Text', 'wpssp_tw', 'Der übergebene Texte <code>de_DE</code>er auf 120 Zeichen gekürzt und beim letzten Leerzeichen mit &hellip; ersetzt.');
		new InputField( 'services_twitter_display_name', 'Anzeigename', 'wpssp_tw', 'Schreibweise des Service in den Optionen' );
		new InputField( 'services_twitter_txt_info', 'Info-Text', 'wpssp_tw', 'MouseOver-Text des Empfehlen-Buttons' );
		new InputField( 'services_twitter_txt_twitter_on', 'Statusmeldung <code>on</code>', 'wpssp_tw', 'Text-Entsprechung der Schalter-Grafik im eingeschalteten Zustand, in der Regel nicht sichtbar für den User');
		new InputField( 'services_twitter_txt_twitter_off', 'Statusmeldung <code>off</code>', 'wpssp_tw', 'Text-Entsprechung der Schalter-Grafik im ausgeschalteten Zustand, in der Regel nicht sichtbar für den User');
		new InputField( 'services_twitter_referrer_track', 'Referrer Track', 'wpssp_tw', 'Wird ans Ende der URL gehängt, kann zum Tracken des Referrers genutzt werden', 'code' );

		new InputField( 'services_gplus_status', '<b>Google+-Button anzeigen</b>', 'wpssp_gp', '<code>on</code>, wenn aktiviert, andernfalls <code>off</code>', '', 'checkbox');
		new InputField( 'services_gplus_display_name', 'Anzeigename', 'wpssp_gp', 'Schreibweise des Service in den Optionen' );
		new InputField( 'services_gplus_txt_info', 'Info-Text', 'wpssp_gp', 'MouseOver-Text des Empfehlen-Buttons' );
		new InputField( 'services_gplus_txt_gplus_on', 'Statusmeldung <code>on</code>', 'wpssp_gp', 'Text-Entsprechung der Schalter-Grafik im eingeschalteten Zustand, in der Regel nicht sichtbar für den User');
		new InputField( 'services_gplus_txt_gplus_off', 'Statusmeldung <code>off</code>', 'wpssp_gp', 'Text-Entsprechung der Schalter-Grafik im ausgeschalteten Zustand, in der Regel nicht sichtbar für den User');
		new InputField( 'services_gplus_referrer_track', 'Referrer Track', 'wpssp_gp', 'Wird ans Ende der URL gehängt, kann zum Tracken des Referrers genutzt werden', 'code' );
		new InputField( 'services_gplus_language', 'Sprache', 'wpssp_gp', 'Spracheinstellung, etwa "de"', 'code');
	}
}

class InputField {
	private $name;
	private $caption;
	private $section;
	private $description;
	private $style_class;
	private $type;
	public $value;

	public function __construct($name, $caption, $section, $description, $style_class = '', $type = 'text') {
		$this->name        = $name;
		$this->caption     = $caption;
		$this->section     = $section;
		$this->description = $description;
		$this->style_class = $style_class;
		$this->type        = $type;

		add_settings_field(
			$this->get_id(),
			$this->caption,
			array(__CLASS__, 'create_field'),
			WpsspAdminPage::$page,
			$this->section,
			array ( label_for => $this->name, input_field => $this )
		);
	}

	public function get_input_element() {
		$options = get_option('wpssp_options');
		return sprintf(
			'<input id="%s" name="%s_options[%s]" type="%s" value="%s" class="%s %s" %s/> <span class="description">%s</span>',
			$this->name,
			WPSSP_PREFIX,
			$this->name,
			$this->type,
			$this->value,
			($this->type == "checkbox" ? '' : 'regular-text'),
			$this->style_class,
			($this->type == "checkbox" ? checked( $options[$this->name], 'on', false ) : ''),
			$this->description
		);
	}

	public function get_id() {
		return WPSSP_PREFIX . $this->name;
	}
	
	public function create_field($args) {
		global $Default_options;
		$field   = $args[input_field];
		$options = get_option('wpssp_options');
		$value   = $options[$field->name];
		if ( !$value ) {
			$value = $Default_options[$field->name];
			if ( !isset($value) ) {
				if ( preg_match('/^services_(facebook|twitter|gplus)_(.*)$/', $field->name, $matches ) ) {
					$value = $Default_options[services][$matches[1]][$matches[2]];
				}
			}
		}
		$field->value = $value;
		echo $field->get_input_element();
	}
}
?>