<?php
/*
Plugin Name: WP socialshareprivacy
Plugin URI: http://wordpress.org/extend/plugins/wp-socialshareprivacy/
Version: 0.6.2
Description: Adds 2-click-privacy social buttons (Facebook, Twitter, G+). See <a href="http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html">article on heise online</a>.
Author: Philipp Bochskandl
Text Domain: wp-socialshareprivacy

    Copyright 2012  Philipp Bochskandl

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
    
*/

require_once 'includes/wpssp_admin.php';

define(WPSSP_PREFIX, 'wpssp');
define(BASE_URL, plugins_url('/wp-socialshareprivacy/'));
$Default_options = array(
	info_link      => 'http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html',
	txt_help       => 'Wenn Sie diese Felder durch einen Klick aktivieren, werden Informationen an Facebook, Twitter oder Google in die USA &uuml;bertragen und unter Umst&auml;nden auch dort gespeichert. N&auml;heres erfahren Sie durch einen Klick auf das <em>i</em>.',
	settings_perma => 'Dauerhaft aktivieren und Daten&uuml;ber&shy;tragung zustimmen:',
	cookie_path    => '/',
	cookie_expire  => 365,
	cookie_domain  => '',
	css_path       => BASE_URL . 'socialshareprivacy.css',
	services       => array(
		facebook => array(
			status          => 'on',
			dummy_img       => BASE_URL . 'images/dummy_facebook.png',
			txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Facebook senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
			txt_fb_off      => 'nicht mit Facebook verbunden',
			txt_fb_on       => 'mit Facebook verbunden',
			display_name    => 'Facebook',
			referrer_track  => '',
			language        => 'de_DE'
		),
		twitter  => array(
			status          => 'on',
			dummy_img       => BASE_URL . 'images/dummy_twitter.png',
			txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Twitter senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
			txt_twitter_off => 'nicht mit Twitter verbunden',
			txt_twitter_on  => 'mit Twitter verbunden',
			display_name    => 'Twitter',
			referrer_track  => '',
			tweet_text      => ''
		),
		gplus    => array(
			status          => 'on',
			dummy_img       => BASE_URL . 'images/dummy_gplus.png',
			txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Google+ senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
			txt_gplus_off   => 'nicht mit Google+ verbunden',
			txt_gplus_on    => 'mit Google+ verbunden',
			display_name    => 'Google+',
			referrer_track  => '',
			language        => 'de'
		)
	)
);

	class Wpssp {
	
	function add_content($content = '') {
		global $Default_options;
		
		$setting_options = get_option('wpssp_options' );
		if ( $setting_options ) {
			foreach ( array_keys($Default_options[services]) as $service ) {
				if ( !isset($setting_options['services_' . $service . '_status']) ) {
					$setting_options['services_' . $service . '_status'] = 'off';
				}
			}
			foreach ( $setting_options as $key => $value) {
				if ( isset($value) && strlen($value) ) {
					if ( preg_match('/^services_(facebook|twitter|gplus)_(.*)$/', $key, $matches ) ) {
						$Default_options[services][$matches[1]][$matches[2]] = $value;
					}
					else {
						$Default_options[$key] = $value;
					}
				} 
			}
		}
		$id = 'socialshareprivacy_' . md5(get_permalink());
		$content .= '<div id="'.$id.'"></div>';
		$content .= "
			<script type=\"text/javascript\">
			(function(\$){
				var options = " . json_encode($Default_options) . ";
				options.cookie_domain = document.location.host;
				options.uri = '" . get_permalink() . "'
				$(document).ready(function(){
					\$('#$id').socialSharePrivacy(options);
				});
			})(jQuery);
			</script>
		";
		$content .= '<!-- end wp-socialshareprivacy -->';
		return $content;
	}
	
	function enqueue_styles() {
		wp_enqueue_style('wp-socialshareprivacy', '/wp-content/plugins/wp-socialshareprivacy/socialshareprivacy.css');
	}
	 
	function enqueue_scripts() {
		wp_enqueue_script('jquery');
		wp_enqueue_script('wp-socialshareprivacy', '/wp-content/plugins/wp-socialshareprivacy/jquery.socialshareprivacy.min.js');
	}
	
	function create_admin_menu() {
		
		// page_title, menu_title, capability, menu_slug, callback?
		add_options_page(
			'WP socialshareprivacy Settings',
			'WP socialshareprivacy',
			'administrator',
			'wp-socialshareprivacy',
			array( 'Wpssp', 'wpssp_settings_page' )
		);
	
		add_action( 'admin_init', array( 'WpsspAdminPage', 'init' ) );
	}
	
	function wpssp_settings_page() {
		?>
		<div class="wrap">
			<div class="icon32" id="icon-options-general"></div>
			<h2>WP socialshareprivacy</h2>
			<form action="options.php" method="post">
			<?php settings_fields('wpssp-settings-group'); ?>
			<?php do_settings_sections('wpssp'); ?>
			
		    <p class="submit">
		    <input type="submit" class="button-primary" value="<?php _e('Änderungen übernehmen') ?>" />
		    </p>
			</form>
			<script type="text/javascript">
			(function($){
				$(document).ready(function() {
					$('input[id*="status"]').change(status_watcher).each(status_watcher);
				});
				function status_watcher() {
					var checkbox = $(this);
					checkbox.parents('table.form-table').find('tr:not(:has(input[id*=status]))').each(function() {
						if ( checkbox.attr('checked') ) {
							$(this).show("normal");
						}
						else {
							$(this).hide("normal");
						}
					});
				}
			})(jQuery);
			</script>
		</div>
		
		<?php
	}
	
	static function run() {
		
		// Frontend
		wp_enqueue_script("jquery");
		add_filter('the_content', array( 'Wpssp','add_content' ) );
		add_action( 'wp_print_scripts', array( 'Wpssp', 'enqueue_scripts' ) );
		add_action( 'wp_print_styles', array( 'Wpssp','enqueue_styles' ) );
		
		// Backend
		if ( is_admin() ) {
			add_action('admin_menu', array( 'Wpssp', 'create_admin_menu' ) );
		}
	}
	
}

Wpssp::run();

?>